==> haskell-skylighting-0.6-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.6
id: skylighting-0.6-8rxNLU1YZigE6dGYhRoX3l
key: skylighting-0.6-8rxNLU1YZigE6dGYhRoX3l
license: GPL-2
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Skylighting Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Parser Skylighting.Regex
    Skylighting.Styles Skylighting.Syntax Skylighting.Tokenizer
    Skylighting.Types
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Diff Skylighting.Syntax.Djangotemplate
                Skylighting.Syntax.Dockerfile Skylighting.Syntax.Dot
                Skylighting.Syntax.Doxygen Skylighting.Syntax.Doxygenlua
                Skylighting.Syntax.Dtd Skylighting.Syntax.Eiffel
                Skylighting.Syntax.Elixir Skylighting.Syntax.Email
                Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
                Skylighting.Syntax.Fortran Skylighting.Syntax.Fsharp
                Skylighting.Syntax.Gcc Skylighting.Syntax.Glsl
                Skylighting.Syntax.Gnuassembler Skylighting.Syntax.Go
                Skylighting.Syntax.Hamlet Skylighting.Syntax.Haskell
                Skylighting.Syntax.Haxe Skylighting.Syntax.Html
                Skylighting.Syntax.Idris Skylighting.Syntax.Ini
                Skylighting.Syntax.Isocpp Skylighting.Syntax.Java
                Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
                Skylighting.Syntax.Json Skylighting.Syntax.Jsp
                Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
                Skylighting.Syntax.Latex Skylighting.Syntax.Lex
                Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
                Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
                Skylighting.Syntax.Lua Skylighting.Syntax.M4
                Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
                Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
                Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
                Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
                Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
                Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
                Skylighting.Syntax.Monobasic Skylighting.Syntax.Nasm
                Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
                Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
                Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
                Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
                Skylighting.Syntax.Php Skylighting.Syntax.Pike
                Skylighting.Syntax.Postscript Skylighting.Syntax.Powershell
                Skylighting.Syntax.Prolog Skylighting.Syntax.Pure
                Skylighting.Syntax.Purebasic Skylighting.Syntax.Python
                Skylighting.Syntax.R Skylighting.Syntax.Relaxng
                Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
                Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
                Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
                Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
                Skylighting.Syntax.Sci Skylighting.Syntax.Sed
                Skylighting.Syntax.Sgml Skylighting.Syntax.SqlMysql
                Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Sql
                Skylighting.Syntax.Tcl Skylighting.Syntax.Tcsh
                Skylighting.Syntax.Texinfo Skylighting.Syntax.Verilog
                Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
                Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
                Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
                Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh
abi: 5e7eeb4b7c72b1a5b2ab7fa836480c79
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/skylighting-0.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/skylighting-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/skylighting-0.6
hs-libraries: HSskylighting-0.6-8rxNLU1YZigE6dGYhRoX3l
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj binary-0.8.5.1
    bytestring-0.10.8.2 directory-1.3.0.2 filepath-1.4.1.2
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    hxt-9.3.1.16-C0YGU2ICocQ91ULlGGH5PG
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO containers-0.5.10.2
    ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7
    colour-2.3.4-Ga6yBh95iV34FXzxXxoROF
    regex-pcre-0.94.4-Bcqev1Te4vN4WejwR7k3Sl
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             hxt-9.3.1.16-C0YGU2ICocQ91ULlGGH5PG=47c1e7b9545cc5d75881ed018bcdb1c9
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO=5b9e50f475d80821e5ba250ac60c1064
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7=90aaa595726b3421fbff142dea995314
             colour-2.3.4-Ga6yBh95iV34FXzxXxoROF=f36a892291922aff6a465f9184182662
             regex-pcre-0.94.4-Bcqev1Te4vN4WejwR7k3Sl=f543f422a42d78abae2fadbc82caacb8
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.7.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.7.1
id: skylighting-0.7.1-39PIPqA87Pi8IktdP2KMY4
key: skylighting-0.7.1-39PIPqA87Pi8IktdP2KMY4
license: GPL-2
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT:Skylighting.Types
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Diff Skylighting.Syntax.Djangotemplate
                Skylighting.Syntax.Dockerfile Skylighting.Syntax.Dot
                Skylighting.Syntax.Doxygen Skylighting.Syntax.Doxygenlua
                Skylighting.Syntax.Dtd Skylighting.Syntax.Eiffel
                Skylighting.Syntax.Elixir Skylighting.Syntax.Email
                Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
                Skylighting.Syntax.Fortran Skylighting.Syntax.Fsharp
                Skylighting.Syntax.Gcc Skylighting.Syntax.Glsl
                Skylighting.Syntax.Gnuassembler Skylighting.Syntax.Go
                Skylighting.Syntax.Hamlet Skylighting.Syntax.Haskell
                Skylighting.Syntax.Haxe Skylighting.Syntax.Html
                Skylighting.Syntax.Idris Skylighting.Syntax.Ini
                Skylighting.Syntax.Isocpp Skylighting.Syntax.Java
                Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
                Skylighting.Syntax.Json Skylighting.Syntax.Jsp
                Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
                Skylighting.Syntax.Latex Skylighting.Syntax.Lex
                Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
                Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
                Skylighting.Syntax.Lua Skylighting.Syntax.M4
                Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
                Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
                Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
                Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
                Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
                Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
                Skylighting.Syntax.Monobasic Skylighting.Syntax.Nasm
                Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
                Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
                Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
                Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
                Skylighting.Syntax.Php Skylighting.Syntax.Pike
                Skylighting.Syntax.Postscript Skylighting.Syntax.Powershell
                Skylighting.Syntax.Prolog Skylighting.Syntax.Pure
                Skylighting.Syntax.Purebasic Skylighting.Syntax.Python
                Skylighting.Syntax.R Skylighting.Syntax.Relaxng
                Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
                Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
                Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
                Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
                Skylighting.Syntax.Sci Skylighting.Syntax.Sed
                Skylighting.Syntax.Sgml Skylighting.Syntax.SqlMysql
                Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Sql
                Skylighting.Syntax.Tcl Skylighting.Syntax.Tcsh
                Skylighting.Syntax.Texinfo Skylighting.Syntax.Verilog
                Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
                Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
                Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
                Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh
abi: 4c18fa262cdfff29e5de6505157cc3b3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/skylighting-0.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/skylighting-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/skylighting-0.7.1
hs-libraries: HSskylighting-0.7.1-39PIPqA87Pi8IktdP2KMY4
depends:
    base-4.10.1.0 skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj binary-0.8.5.1
    bytestring-0.10.8.2 directory-1.3.0.2 filepath-1.4.1.2
    aeson-1.2.4.0-AtrYaitd3jMG1bjpyUF0Ei
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    attoparsec-0.13.2.2-9YjPD6eySTr2XtEq1V3i2t
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    hxt-9.3.1.16-C0YGU2ICocQ91ULlGGH5PG
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO containers-0.5.10.2
    ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7
    colour-2.3.4-Ga6yBh95iV34FXzxXxoROF
    regex-pcre-0.94.4-Bcqev1Te4vN4WejwR7k3Sl
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             skylighting-core-0.7.1-HHgOJTuhPBx3dZrQDnD7CT=6f88c46fb03b93dc1d38f50665ad0514
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             aeson-1.2.4.0-AtrYaitd3jMG1bjpyUF0Ei=cd659b4105a2c797bfc8b13b8ea3a331
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             attoparsec-0.13.2.2-9YjPD6eySTr2XtEq1V3i2t=e275f62d517bb5373c55830561137640
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             hxt-9.3.1.16-C0YGU2ICocQ91ULlGGH5PG=47c1e7b9545cc5d75881ed018bcdb1c9
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             blaze-html-0.9.0.1-HqpSz28u1FiCfAogiiZCfO=5b9e50f475d80821e5ba250ac60c1064
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7=90aaa595726b3421fbff142dea995314
             colour-2.3.4-Ga6yBh95iV34FXzxXxoROF=f36a892291922aff6a465f9184182662
             regex-pcre-0.94.4-Bcqev1Te4vN4WejwR7k3Sl=f543f422a42d78abae2fadbc82caacb8
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
